# zincsearch-sdk
Zinc Search engine API documents https://docs.zincsearch.com

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.2.4
- Package version: 0.2.4
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.zincsearch.com](https://www.zincsearch.com)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/zinclabs/sdk-python-zincsearch.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/zinclabs/sdk-python-zincsearch.git`)

Then import the package:
```python
import zincsearch_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import zincsearch_sdk
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import zincsearch_sdk
from pprint import pprint
from zincsearch_sdk.api import document
from zincsearch_sdk.model.meta_http_response_document import MetaHTTPResponseDocument
from zincsearch_sdk.model.meta_http_response_error import MetaHTTPResponseError
from zincsearch_sdk.model.meta_http_response_id import MetaHTTPResponseID
from zincsearch_sdk.model.meta_http_response_record_count import MetaHTTPResponseRecordCount
# Defining the host is optional and defaults to http://localhost:4080
# See configuration.py for a list of all supported configuration parameters.
configuration = zincsearch_sdk.Configuration(
    host = "http://localhost:4080"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = zincsearch_sdk.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)


# Enter a context with an instance of the API client
with zincsearch_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = document.Document(api_client)
    query = "query_example" # str | Query

    try:
        # Bulk documents
        api_response = api_instance.bulk(query)
        pprint(api_response)
    except zincsearch_sdk.ApiException as e:
        print("Exception when calling Document->bulk: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:4080*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Document* | [**bulk**](docs/Document.md#bulk) | **POST** /api/_bulk | Bulk documents
*Document* | [**delete**](docs/Document.md#delete) | **DELETE** /api/{index}/_doc/{id} | Delete document
*Document* | [**es_bulk**](docs/Document.md#es_bulk) | **POST** /es/_bulk | ES bulk documents
*Document* | [**index**](docs/Document.md#index) | **POST** /api/{index}/_doc | Create or update document
*Document* | [**index_with_id**](docs/Document.md#index_with_id) | **PUT** /api/{index}/_doc/{id} | Create or update document with id
*Document* | [**update**](docs/Document.md#update) | **POST** /api/{index}/_update/{id} | Update document with id
*Index* | [**analyze**](docs/Index.md#analyze) | **POST** /api/_analyze | Analyze
*Index* | [**analyze_index**](docs/Index.md#analyze_index) | **POST** /api/{index}/_analyze | Analyze
*Index* | [**create**](docs/Index.md#create) | **POST** /api/index | Create index
*Index* | [**create_template**](docs/Index.md#create_template) | **POST** /es/_index_template | Create update index template
*Index* | [**delete**](docs/Index.md#delete) | **DELETE** /api/index/{index} | Delete index
*Index* | [**delete_template**](docs/Index.md#delete_template) | **DELETE** /es/_index_template/{name} | Delete template
*Index* | [**get_mapping**](docs/Index.md#get_mapping) | **GET** /api/{index}/_mapping | Get index mappings
*Index* | [**get_settings**](docs/Index.md#get_settings) | **GET** /api/{index}/_settings | Get index settings
*Index* | [**get_template**](docs/Index.md#get_template) | **GET** /es/_index_template/{name} | Get index template
*Index* | [**list**](docs/Index.md#list) | **GET** /api/index | List indexes
*Index* | [**list_templates**](docs/Index.md#list_templates) | **GET** /es/_index_template | List index teplates
*Index* | [**refresh**](docs/Index.md#refresh) | **POST** /api/index/{index}/refresh | Resfresh index
*Index* | [**set_mapping**](docs/Index.md#set_mapping) | **PUT** /api/{index}/_mapping | Set index mappings
*Index* | [**set_settings**](docs/Index.md#set_settings) | **PUT** /api/{index}/_settings | Set index Settings
*Index* | [**update_template**](docs/Index.md#update_template) | **PUT** /es/_index_template/{name} | Create update index template
*Search* | [**msearch**](docs/Search.md#msearch) | **POST** /es/_msearch | Search V2 MultipleSearch for compatible ES
*Search* | [**search**](docs/Search.md#search) | **POST** /es/{index}/_search | Search V2 DSL for compatible ES
*Search* | [**search_v1**](docs/Search.md#search_v1) | **POST** /api/{index}/_search | Search V1
*User* | [**create**](docs/User.md#create) | **POST** /api/user | Create user
*User* | [**delete**](docs/User.md#delete) | **DELETE** /api/user/{id} | Delete user
*User* | [**list**](docs/User.md#list) | **GET** /api/user | List user
*User* | [**login**](docs/User.md#login) | **POST** /api/login | Login
*User* | [**update**](docs/User.md#update) | **PUT** /api/user | Update user
*Default* | [**healthz**](docs/Default.md#healthz) | **GET** /healthz | Get healthz
*Default* | [**version**](docs/Default.md#version) | **GET** /version | Get version


## Documentation For Models

 - [AggregationHistogramBound](docs/AggregationHistogramBound.md)
 - [AuthLoginRequest](docs/AuthLoginRequest.md)
 - [AuthLoginResponse](docs/AuthLoginResponse.md)
 - [AuthLoginUser](docs/AuthLoginUser.md)
 - [CoreIndex](docs/CoreIndex.md)
 - [IndexAnalyzeResponse](docs/IndexAnalyzeResponse.md)
 - [IndexAnalyzeResponseToken](docs/IndexAnalyzeResponseToken.md)
 - [MetaAggregationAutoDateHistogram](docs/MetaAggregationAutoDateHistogram.md)
 - [MetaAggregationDateHistogram](docs/MetaAggregationDateHistogram.md)
 - [MetaAggregationDateRange](docs/MetaAggregationDateRange.md)
 - [MetaAggregationHistogram](docs/MetaAggregationHistogram.md)
 - [MetaAggregationIPRange](docs/MetaAggregationIPRange.md)
 - [MetaAggregationMetric](docs/MetaAggregationMetric.md)
 - [MetaAggregationRange](docs/MetaAggregationRange.md)
 - [MetaAggregationResponse](docs/MetaAggregationResponse.md)
 - [MetaAggregations](docs/MetaAggregations.md)
 - [MetaAggregationsTerms](docs/MetaAggregationsTerms.md)
 - [MetaAnalyzer](docs/MetaAnalyzer.md)
 - [MetaBoolQuery](docs/MetaBoolQuery.md)
 - [MetaDateRange](docs/MetaDateRange.md)
 - [MetaExistsQuery](docs/MetaExistsQuery.md)
 - [MetaFuzzyQuery](docs/MetaFuzzyQuery.md)
 - [MetaHTTPResponse](docs/MetaHTTPResponse.md)
 - [MetaHTTPResponseDocument](docs/MetaHTTPResponseDocument.md)
 - [MetaHTTPResponseError](docs/MetaHTTPResponseError.md)
 - [MetaHTTPResponseID](docs/MetaHTTPResponseID.md)
 - [MetaHTTPResponseIndex](docs/MetaHTTPResponseIndex.md)
 - [MetaHTTPResponseRecordCount](docs/MetaHTTPResponseRecordCount.md)
 - [MetaHTTPResponseTemplate](docs/MetaHTTPResponseTemplate.md)
 - [MetaHealthzResponse](docs/MetaHealthzResponse.md)
 - [MetaHighlight](docs/MetaHighlight.md)
 - [MetaHit](docs/MetaHit.md)
 - [MetaHits](docs/MetaHits.md)
 - [MetaIPRange](docs/MetaIPRange.md)
 - [MetaIdsQuery](docs/MetaIdsQuery.md)
 - [MetaIndexAnalysis](docs/MetaIndexAnalysis.md)
 - [MetaIndexSettings](docs/MetaIndexSettings.md)
 - [MetaIndexShard](docs/MetaIndexShard.md)
 - [MetaIndexSimple](docs/MetaIndexSimple.md)
 - [MetaIndexTemplate](docs/MetaIndexTemplate.md)
 - [MetaMappings](docs/MetaMappings.md)
 - [MetaMatchBoolPrefixQuery](docs/MetaMatchBoolPrefixQuery.md)
 - [MetaMatchPhrasePrefixQuery](docs/MetaMatchPhrasePrefixQuery.md)
 - [MetaMatchPhraseQuery](docs/MetaMatchPhraseQuery.md)
 - [MetaMatchQuery](docs/MetaMatchQuery.md)
 - [MetaMultiMatchQuery](docs/MetaMultiMatchQuery.md)
 - [MetaPrefixQuery](docs/MetaPrefixQuery.md)
 - [MetaProperty](docs/MetaProperty.md)
 - [MetaQuery](docs/MetaQuery.md)
 - [MetaQueryStringQuery](docs/MetaQueryStringQuery.md)
 - [MetaRange](docs/MetaRange.md)
 - [MetaRangeQuery](docs/MetaRangeQuery.md)
 - [MetaRegexpQuery](docs/MetaRegexpQuery.md)
 - [MetaSearchResponse](docs/MetaSearchResponse.md)
 - [MetaShards](docs/MetaShards.md)
 - [MetaSimpleQueryStringQuery](docs/MetaSimpleQueryStringQuery.md)
 - [MetaTemplate](docs/MetaTemplate.md)
 - [MetaTemplateTemplate](docs/MetaTemplateTemplate.md)
 - [MetaTermQuery](docs/MetaTermQuery.md)
 - [MetaTotal](docs/MetaTotal.md)
 - [MetaUser](docs/MetaUser.md)
 - [MetaVersionResponse](docs/MetaVersionResponse.md)
 - [MetaWildcardQuery](docs/MetaWildcardQuery.md)
 - [MetaZincQuery](docs/MetaZincQuery.md)
 - [V1AggregationBucket](docs/V1AggregationBucket.md)
 - [V1AggregationDateRange](docs/V1AggregationDateRange.md)
 - [V1AggregationNumberRange](docs/V1AggregationNumberRange.md)
 - [V1AggregationParams](docs/V1AggregationParams.md)
 - [V1AggregationResponse](docs/V1AggregationResponse.md)
 - [V1Hit](docs/V1Hit.md)
 - [V1Hits](docs/V1Hits.md)
 - [V1QueryHighlight](docs/V1QueryHighlight.md)
 - [V1QueryParams](docs/V1QueryParams.md)
 - [V1SearchResponse](docs/V1SearchResponse.md)
 - [V1Total](docs/V1Total.md)
 - [V1ZincQuery](docs/V1ZincQuery.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in zincsearch_sdk.apis and zincsearch_sdk.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from zincsearch_sdk.api.default_api import DefaultApi`
- `from zincsearch_sdk.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import zincsearch_sdk
from zincsearch_sdk.apis import *
from zincsearch_sdk.models import *
```

